==> qtjambi-qt3dcore-debuginfo-linux-x64-5.15.18.jar: sources/QtJambi3DCore/QComponentRemovedChange_shell.cpp <==
#include "QComponentRemovedChange_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QComponentRemovedChange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QComponentRemovedChange")
    Qt3DCore::QComponentRemovedChange *_ptr = reinterpret_cast<Qt3DCore::QComponentRemovedChange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QComponentRemovedChange_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QComponentRemovedChange_shell) ); }

jmethodID QComponentRemovedChange_shell::__shell_javaMethod(int pos) const { return QComponentRemovedChange_shell::__shell()->javaMethod(typeid(Qt3DCore::QComponentRemovedChange), pos); }

// emitting (writeShellConstructor)
QComponentRemovedChange_shell::QComponentRemovedChange_shell(const Qt3DCore::QComponent* component0, const Qt3DCore::QEntity* entity1)
    : Qt3DCore::QComponentRemovedChange(component0, entity1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QComponentRemovedChange::QComponentRemovedChange_shell(const Qt3DCore::QComponent* component0, const Qt3DCore::QEntity* entity1)", QComponentRemovedChange_shell::__shell())
    QComponentRemovedChange_shell::__shell()->constructed(typeid(Qt3DCore::QComponentRemovedChange));
}

QComponentRemovedChange_shell::QComponentRemovedChange_shell(const Qt3DCore::QEntity* entity0, const Qt3DCore::QComponent* component1)
    : Qt3DCore::QComponentRemovedChange(entity0, component1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QComponentRemovedChange::QComponentRemovedChange_shell(const Qt3DCore::QEntity* entity0, const Qt3DCore::QComponent* component1)", QComponentRemovedChange_shell::__shell())
    QComponentRemovedChange_shell::__shell()->constructed(typeid(Qt3DCore::QComponentRemovedChange));
}

// emitting (writeShellDestructor)
QComponentRemovedChange_shell::~QComponentRemovedChange_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QComponentRemovedChange::~Qt3DCore::QComponentRemovedChange()", QComponentRemovedChange_shell::__shell())
    QComponentRemovedChange_shell::__shell()->destructed(typeid(Qt3DCore::QComponentRemovedChange));
}

void QComponentRemovedChange_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QComponentRemovedChange_shell*>(ptr)->QComponentRemovedChange_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QComponentRemovedChange));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QComponentRemovedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)
void __qt_construct_Qt3DCore_QComponentRemovedChange_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QComponentRemovedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)")
    jobject component0 = __java_arguments[0].l;
    const Qt3DCore::QComponent* __qt_component0 = qtjambi_cast<const Qt3DCore::QComponent* >(__jni_env, component0);
    jobject entity1 = __java_arguments[1].l;
    const Qt3DCore::QEntity* __qt_entity1 = qtjambi_cast<const Qt3DCore::QEntity* >(__jni_env, entity1);
    Qt3DCore::QComponentRemovedChange *__qt_this = new(__qtjambi_ptr) QComponentRemovedChange_shell(__qt_component0, __qt_entity1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QComponentRemovedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)
void __qt_construct_Qt3DCore_QComponentRemovedChange_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QComponentRemovedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)")
    jobject entity0 = __java_arguments[0].l;
    const Qt3DCore::QEntity* __qt_entity0 = qtjambi_cast<const Qt3DCore::QEntity* >(__jni_env, entity0);
    jobject component1 = __java_arguments[1].l;
    const Qt3DCore::QComponent* __qt_component1 = qtjambi_cast<const Qt3DCore::QComponent* >(__jni_env, component1);
    Qt3DCore::QComponentRemovedChange *__qt_this = new(__qtjambi_ptr) QComponentRemovedChange_shell(__qt_entity0, __qt_component1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QComponentRemovedChange_shell
void __qt_destruct_Qt3DCore_QComponentRemovedChange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QComponentRemovedChange")
    reinterpret_cast<QComponentRemovedChange_shell*>(ptr)->~QComponentRemovedChange_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QComponentRemovedChange_initialize_1native__Lio_qt_qt3d_core_QComponentRemovedChange_2Lio_qt_qt3d_core_QComponent_2Lio_qt_qt3d_core_QEntity_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject component0,
 jobject entity1)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = component0;
        arguments[1].l = entity1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QComponentRemovedChange_0, sizeof(QComponentRemovedChange_shell), typeid(Qt3DCore::QComponentRemovedChange), true, &deleter_Qt3DCore_QComponentRemovedChange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QComponentRemovedChange_initialize_1native__Lio_qt_qt3d_core_QComponentRemovedChange_2Lio_qt_qt3d_core_QEntity_2Lio_qt_qt3d_core_QComponent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject entity0,
 jobject component1)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = entity0;
        arguments[1].l = component1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QComponentRemovedChange_1, sizeof(QComponentRemovedChange_shell), typeid(Qt3DCore::QComponentRemovedChange), true, &deleter_Qt3DCore_QComponentRemovedChange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QComponentRemovedChange::componentId()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QComponentRemovedChange_componentId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QComponentRemovedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QComponentRemovedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QComponentRemovedChange::componentId()const", __qt_this)
        Qt3DCore::QNodeId __qt_return_value = __qt_this->componentId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QComponentRemovedChange::componentMetaObject()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QComponentRemovedChange_componentMetaObject_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QComponentRemovedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QComponentRemovedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QComponentRemovedChange::componentMetaObject()const", __qt_this)
        const QMetaObject* __qt_return_value = __qt_this->componentMetaObject();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QComponentRemovedChange::entityId()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QComponentRemovedChange_entityId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QComponentRemovedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QComponentRemovedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QComponentRemovedChange::entityId()const", __qt_this)
        Qt3DCore::QNodeId __qt_return_value = __qt_this->entityId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QComponentRemovedChange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QComponentRemovedChange>("Qt3DCore::QComponentRemovedChange", "io/qt/qt3d/core/QComponentRemovedChange");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QComponentRemovedChange, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QComponentRemovedChange_0, "Lio/qt/qt3d/core/QComponent;Lio/qt/qt3d/core/QEntity;")
       ,ConstructorInfo(&__qt_construct_Qt3DCore_QComponentRemovedChange_1, "Lio/qt/qt3d/core/QEntity;Lio/qt/qt3d/core/QComponent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QComponentRemovedChange);
    registerSizeOfShell(typeId, sizeof(QComponentRemovedChange_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QSceneChange, Qt3DCore::QComponentRemovedChange>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-linux-x64-5.15.20.jar: sources/QtJambi3DCore/QComponentRemovedChange_shell.cpp <==
#include "QComponentRemovedChange_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QComponentRemovedChange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QComponentRemovedChange")
    Qt3DCore::QComponentRemovedChange *_ptr = reinterpret_cast<Qt3DCore::QComponentRemovedChange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QComponentRemovedChange_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QComponentRemovedChange_shell) ); }

jmethodID QComponentRemovedChange_shell::__shell_javaMethod(int pos) const { return QComponentRemovedChange_shell::__shell()->javaMethod(typeid(Qt3DCore::QComponentRemovedChange), pos); }

// emitting (writeShellConstructor)
QComponentRemovedChange_shell::QComponentRemovedChange_shell(const Qt3DCore::QComponent* component0, const Qt3DCore::QEntity* entity1)
    : Qt3DCore::QComponentRemovedChange(component0, entity1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QComponentRemovedChange::QComponentRemovedChange_shell(const Qt3DCore::QComponent* component0, const Qt3DCore::QEntity* entity1)", QComponentRemovedChange_shell::__shell())
    QComponentRemovedChange_shell::__shell()->constructed(typeid(Qt3DCore::QComponentRemovedChange));
}

QComponentRemovedChange_shell::QComponentRemovedChange_shell(const Qt3DCore::QEntity* entity0, const Qt3DCore::QComponent* component1)
    : Qt3DCore::QComponentRemovedChange(entity0, component1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QComponentRemovedChange::QComponentRemovedChange_shell(const Qt3DCore::QEntity* entity0, const Qt3DCore::QComponent* component1)", QComponentRemovedChange_shell::__shell())
    QComponentRemovedChange_shell::__shell()->constructed(typeid(Qt3DCore::QComponentRemovedChange));
}

// emitting (writeShellDestructor)
QComponentRemovedChange_shell::~QComponentRemovedChange_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QComponentRemovedChange::~Qt3DCore::QComponentRemovedChange()", QComponentRemovedChange_shell::__shell())
    QComponentRemovedChange_shell::__shell()->destructed(typeid(Qt3DCore::QComponentRemovedChange));
}

void QComponentRemovedChange_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QComponentRemovedChange_shell*>(ptr)->QComponentRemovedChange_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QComponentRemovedChange));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QComponentRemovedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)
void __qt_construct_Qt3DCore_QComponentRemovedChange_const_Qt3DCore_QComponent_ptr_const_Qt3DCore_QEntity_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QComponentRemovedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)")
    jobject component0 = __java_arguments[0].l;
    const Qt3DCore::QComponent* __qt_component0 = qtjambi_cast<const Qt3DCore::QComponent* >(__jni_env, component0);
    jobject entity1 = __java_arguments[1].l;
    const Qt3DCore::QEntity* __qt_entity1 = qtjambi_cast<const Qt3DCore::QEntity* >(__jni_env, entity1);
    Qt3DCore::QComponentRemovedChange *__qt_this = new(__qtjambi_ptr) QComponentRemovedChange_shell(__qt_component0, __qt_entity1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QComponentRemovedChange_initialize_1native__Lio_qt_qt3d_core_QComponentRemovedChange_2Lio_qt_qt3d_core_QComponent_2Lio_qt_qt3d_core_QEntity_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject component0,
 jobject entity1)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = component0;
        arguments[1].l = entity1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QComponentRemovedChange_const_Qt3DCore_QComponent_ptr_const_Qt3DCore_QEntity_ptr, sizeof(QComponentRemovedChange_shell), typeid(Qt3DCore::QComponentRemovedChange), true, &deleter_Qt3DCore_QComponentRemovedChange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QComponentRemovedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)
void __qt_construct_Qt3DCore_QComponentRemovedChange_const_Qt3DCore_QEntity_ptr_const_Qt3DCore_QComponent_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QComponentRemovedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)")
    jobject entity0 = __java_arguments[0].l;
    const Qt3DCore::QEntity* __qt_entity0 = qtjambi_cast<const Qt3DCore::QEntity* >(__jni_env, entity0);
    jobject component1 = __java_arguments[1].l;
    const Qt3DCore::QComponent* __qt_component1 = qtjambi_cast<const Qt3DCore::QComponent* >(__jni_env, component1);
    Qt3DCore::QComponentRemovedChange *__qt_this = new(__qtjambi_ptr) QComponentRemovedChange_shell(__qt_entity0, __qt_component1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QComponentRemovedChange_initialize_1native__Lio_qt_qt3d_core_QComponentRemovedChange_2Lio_qt_qt3d_core_QEntity_2Lio_qt_qt3d_core_QComponent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject entity0,
 jobject component1)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QComponentRemovedChange::QComponentRemovedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = entity0;
        arguments[1].l = component1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QComponentRemovedChange_const_Qt3DCore_QEntity_ptr_const_Qt3DCore_QComponent_ptr, sizeof(QComponentRemovedChange_shell), typeid(Qt3DCore::QComponentRemovedChange), true, &deleter_Qt3DCore_QComponentRemovedChange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QComponentRemovedChange_shell
void __qt_destruct_Qt3DCore_QComponentRemovedChange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QComponentRemovedChange")
    reinterpret_cast<QComponentRemovedChange_shell*>(ptr)->~QComponentRemovedChange_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QComponentRemovedChange::componentId()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QComponentRemovedChange_componentId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QComponentRemovedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QComponentRemovedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QComponentRemovedChange::componentId()const", __qt_this)
        Qt3DCore::QNodeId __qt_return_value = __qt_this->componentId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QComponentRemovedChange::componentMetaObject()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QComponentRemovedChange_componentMetaObject_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QComponentRemovedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QComponentRemovedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QComponentRemovedChange::componentMetaObject()const", __qt_this)
        const QMetaObject* __qt_return_value = __qt_this->componentMetaObject();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QComponentRemovedChange::entityId()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QComponentRemovedChange_entityId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QComponentRemovedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QComponentRemovedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QComponentRemovedChange::entityId()const", __qt_this)
        Qt3DCore::QNodeId __qt_return_value = __qt_this->entityId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QComponentRemovedChange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QComponentRemovedChange>("Qt3DCore::QComponentRemovedChange", "io/qt/qt3d/core/QComponentRemovedChange");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QComponentRemovedChange, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QComponentRemovedChange_const_Qt3DCore_QComponent_ptr_const_Qt3DCore_QEntity_ptr, "Lio/qt/qt3d/core/QComponent;Lio/qt/qt3d/core/QEntity;")
       ,ConstructorInfo(&__qt_construct_Qt3DCore_QComponentRemovedChange_const_Qt3DCore_QEntity_ptr_const_Qt3DCore_QComponent_ptr, "Lio/qt/qt3d/core/QEntity;Lio/qt/qt3d/core/QComponent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QComponentRemovedChange);
    registerSizeOfShell(typeId, sizeof(QComponentRemovedChange_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QSceneChange, Qt3DCore::QComponentRemovedChange>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
